@@ -57,6 +57,7 @@ def plot_predictions_hierarchy(
     std_predictions_by_group_ele,
     group_elements,
     forecast_horizon,
+    algorithm
 ):
     (
         true_values_to_plot,
@@ -122,6 +123,7 @@ def plot_predictions_hierarchy(
         )
 
         axs[i].set_title(f"{group}")
+    plt.suptitle(f'Results for different groups for the {algorithm} algorithm', fontsize=16)
     plt.tight_layout()
     axs[i].legend()
     plt.show()
@@ -214,8 +216,9 @@ def boxplot(datasets_err: Dict[str, pd.DataFrame], err: str, figsize: tuple = (2
     datasets = []
     dfs = []
     for dataset, df in datasets_err.items():
-        datasets.append(dataset)
-        dfs.append(df)
+        if df is not None:
+            datasets.append(dataset)
+            dfs.append(df)
     n_datasets = len(datasets)
     if n_datasets == 1:
         _, ax = plt.subplots(1, 1, figsize=figsize)
